#!/usr/bin/python

# RSS Mix Tape
# Copyright 2003, David "Novalis" Turner <novalis@fsf.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from qt import *

from ConfigEditor import ConfigEditor
import Interval

import config
import re

class ConfigEditorImpl (ConfigEditor):
    def __init__ (self):
        ConfigEditor.__init__ (self)
        secs = Interval.revtimes.keys ()
        secs.sort ()
        self.minUpdate.insertStrList ([Interval.revtimes [x] for x in secs])

        #set up the combobox for the minimum update interval
        mi = config.get ("minUpdate")
        if not mi:
            config.set ("minUpdate",
                        Interval.times
                        [str (self.minUpdate.currentText ())])

            #The default should not expire an item in 15 minutes
            self.minUpdate.setCurrentItem (6)
            
        else:
            i = 0
            for s in secs:
                if mi == s:
                    self.minUpdate.setCurrentItem (i)
                    continue
                i += 1

        title = config.get ("title")
        if title:
            self.title.setText (title)

        link = config.get ("link")
        if link:
            self.link.setText (link)

        description = config.get ("description")
        if description:
            self.description.setText (description)

        outputDir = config.get ("outputDir")
        if outputDir:
            self.outputDir.setText (outputDir)
            
        rx = QRegExp ("[^/]+")

        self.newCategory.setValidator (QRegExpValidator (rx, self.newCategory))
        self.cats = config.getCategories ()
        self.categories.insertStrList (self.cats)

    def add_category (self):
        text = str (self.newCategory.text ())
        if len (text):
            self.cats.append (text)
            self.categories.insertItem (text)
            self.newCategory.setText ("")

    def delete_category (self):
        i = self.categories.currentItem ()
        if i == -1:
            return
        self.categories.removeItem (i)
        self.cats = self.cats [0:i] + self.cats [i + 1:-1]

    def accept (self):
        config.set ("minUpdate",
                    Interval.times [str (self.minUpdate.currentText ())])
        config.set ("title", str (self.title.text ()))
        config.set ("link", str (self.link.text ()))
        config.set ("description", str (self.description.text ()))
        config.set ("outputDir", str (self.outputDir.text ()))
        config.setCategories (self.cats)
        config.save ()
        ConfigEditor.accept (self)
