#!/usr/bin/python

# RSS Mix Tape
# Copyright 2003, David "Novalis" Turner <novalis@fsf.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import config

import time

class Post:
    def __init__ (self, feed, date, title, link, text, comment = '',
                  posted = 'not posted', deleted = 0, generated = 0, id = -1):
        self.feed = self.unicodify (feed)
        self.date = int (date)
        self.title = self.unicodify (title or '')
        self.link = self.unicodify (link or '')
        self.text = self.unicodify (text or '')
        if not comment:
            comment = "I found this on " + feed + ":"
        self.comment = self.unicodify (comment)
        self.posted = self.unicodify (posted)
        self.deleted = int (deleted)
        self.generated = int (generated)
        
        if id == -1:
            id = config.counter ()
        self.id = id

    def unicodify (self, value):
        if type (value) == unicode:
            return value
        else:
            return unicode (value, 'utf-8')


    def toValue (self):
        x = u"\0".join ([self.feed, str (self.date), self.title, self.link,
                         self.text, self.comment, self.posted,
                         str (self.deleted), str (self.generated)])

        #FIXME: I think this fails sometimes, but I forgot to save
        #the case that did it.  Oops.
        return x.encode ('utf-8', 'replace')


    def shouldGenerate (self):
        if not self.posted or self.posted == "not posted":
            return 0
        if self.generated == 0:
            return 1
        if self.generated - time.time () < int (config.get ("minUpdate")):
            return 1
        return 0

    def delete (self):

        """Delete the post.  Stores the time the deletion happened, so
        the post can be purged after a certain amount of time"""
        
        self.deleted = int (time.time ())
